import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  max,
  scalePoint,
  axisLeft,
  axisBottom,
  format,
  extent,
  timeDay,
  line,
  area,
  curveBasis,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  const xValue = (d) => d.Year;
  const xAxisLabel = 'Year';
  const yValue = (d) => d.Bitcoin_Price;
  const yAxisLabel = 'Bitcoin_Price';
  const circleRadius = 10;
  const margin = {
    top: 35,
    right: 40,
    left: 90,
    bottom: 40,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  console.log(xValue);

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, ${margin.top})`,
    );

  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(13)
    .ticks(timeDay.every(2));

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();

  yAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', -40)
    .attr('x', -innerHeight / 2)
    .attr('fill', 'black')
    .attr('transform', 'rotate(-90)')
    .style('text-anchor', 'middle')
    .text(yAxisLabel);

  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', 33)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black')
    .text(xAxisLabel);

  const areaGenerator = area()
    .x((d) => xScale(xValue(d)))
    .y0(innerHeight)
    .y1((d) => yScale(yValue(d)))
    .curve(curveBasis);

  g.append('path')
    .attr('class', 'area-path')
    .attr('d', areaGenerator(data));

  g.append('text')
    .attr('class', 'title')
    .attr('y', -10)
    .text('A Month in Sheatown');
};

csv('data.csv').then((data) => {
  data.forEach((d) => {
    d.Bitcoin_Price = +d.Bitcoin_Price;
    d.Year = d.Year;
    console.log(d.Year);
  });
  render(data);
});
